@@ -49,12 +49,12 @@ def init(args):
     tab = '    '
     half_tab = '  '
 
-
-    if not os.path.isfile('~/.nwborglabsrc.org'):
+    home = expanduser("~")
+    if not os.path.isfile(os.path.join(home,'.nwborglabsrc.org')):
         print('First nwborglab initialization! Setting up... ')
         with open('/'.join(nwborglab.__file__.split('/')[:-1]) + '/' + '.nwborglabsrc.org', 'r') as f: # TODO replace this with where the package will be
             content = f.read()
-        home = expanduser("~")
+
         with open(os.path.join(home,'.nwborglabsrc.org'), 'w') as f: # TODO replace this with where the package will be
             f.write(content)
 
@@ -65,7 +65,7 @@ def init(args):
     # TODO fill out the .nwborg
     init_org = SAPOFTO.SAPOFTO('.nwborglab')
     content = ''
-    with open('~/.nwborglabsrc.org', 'r') as f: # TODO replace this with where the package will be
+    with open(os.path.join(home,'.nwborglabsrc.org'), 'r') as f: # TODO replace this with where the package will be
         content = f.read()
     with open('.nwborglab.org', 'w') as f:
         f.write(content)
